@@ -173,6 +173,25 @@ class UpdateUserResult(ABC):
         self.status = status
 
 
+class DeleteUserInfoResult(ABC):
+    def __init__(self, status: Literal['OK', 'UNKNOWN_USER_ID_ERROR']):
+        self.status = status
+        self.is_ok = False
+        self.is_unknown_user_id_error = False
+
+
+class DeleteUserInfoOkResult(DeleteUserInfoResult):
+    def __init__(self):
+        super().__init__('OK')
+        self.is_ok = True
+
+
+class DeleteUserInfoUnknownUserIdErrorResult(DeleteUserInfoResult):
+    def __init__(self):
+        super().__init__('UNKNOWN_USER_ID_ERROR')
+        self.is_unknown_user_id_error = True
+
+
 class UpdateUserOkResult(UpdateUserResult):
     def __init__(self):
         super().__init__('OK')
@@ -258,6 +277,14 @@ class RecipeInterface(ABC):
                           email: Union[str, None], phone_number: Union[str, None], user_context: Dict[str, Any]) -> UpdateUserResult:
         pass
 
+    @abstractmethod
+    async def delete_email_for_user(self, user_id: str, user_context: Dict[str, Any]) -> DeleteUserInfoResult:
+        pass
+
+    @abstractmethod
+    async def delete_phone_number_for_user(self, user_id: str, user_context: Dict[str, Any]) -> DeleteUserInfoResult:
+        pass
+
     @abstractmethod
     async def revoke_all_codes(self,
                                email: Union[str, None], phone_number: Union[str, None], user_context: Dict[str, Any]) -> RevokeAllCodesResult:
